@@ -1,14 +1,8 @@
 #' @title HttpLibAdapaterRegistry
 #' @description http lib adapter registry
-#' @export
-#' @examples
-#' x <- HttpLibAdapaterRegistry$new()
-#' x$register(CrulAdapter$new())
-#' x
-#' x$adapters
-#' x$adapters[[1]]$name
+#' @keywords internal
 HttpLibAdapaterRegistry <- R6::R6Class(
-  'HttpLibAdapaterRegistry',
+  "HttpLibAdapaterRegistry",
   public = list(
     #' @field adapters list
     adapters = NULL,
@@ -17,10 +11,15 @@ HttpLibAdapaterRegistry <- R6::R6Class(
     #' @param x self
     #' @param ... ignored
     print = function(x, ...) {
-      cat("<HttpLibAdapaterRegistry> ", sep = "\n")
+      cat_line("<HttpLibAdapaterRegistry> ")
       for (i in seq_along(self$adapters)) {
-        cat(sprintf("  %s: webmockr:::%s", self$adapters[[i]]$name,
-                    class(self$adapters[[i]])[1]), sep = "\n")
+        cat_line(
+          sprintf(
+            "  %s: webmockr:::%s",
+            self$adapters[[i]]$name,
+            class(self$adapters[[i]])[1]
+          )
+        )
       }
     },
 
@@ -28,9 +27,8 @@ HttpLibAdapaterRegistry <- R6::R6Class(
     #' @param x an http lib adapter, e.g., [CrulAdapter]
     #' @return nothing, registers the library adapter
     register = function(x) {
-      # FIXME: when other adapters supported, change this inherits test
       if (!inherits(x, c("CrulAdapter", "HttrAdapter", "Httr2Adapter"))) {
-        stop("'x' must be an adapter, such as CrulAdapter", call. = FALSE)
+        abort("'x' must be an adapter, such as CrulAdapter")
       }
       self$adapters <- c(self$adapters, x)
     }
