@@ -1,11 +1,13 @@
 #' Build a crul response
 #' @export
+#' @keywords internal
 #' @param req a request
 #' @param resp a response
 #' @return a crul response
 build_crul_response <- function(req, resp) {
   # prep headers
-  if (grepl("^ftp://", resp$url %||% "")) { # in case uri_regex only
+  if (grepl("^ftp://", resp$url %||% "")) {
+    # in case uri_regex only
     headers <- list()
   } else {
     hds <- resp$headers
@@ -23,17 +25,20 @@ build_crul_response <- function(req, resp) {
       if (is.null(hh) || nchar(hh) == 0) {
         headers <- list()
       } else {
-        headers <- lapply(curl::parse_headers(hh, multiple = TRUE), 
-          crul_headers_parse)
+        headers <- lapply(
+          curl::parse_headers(hh, multiple = TRUE),
+          crul_headers_parse
+        )
       }
     }
   }
 
   crul::HttpResponse$new(
     method = req$method,
-    url = req$url$url,
+    # if resp URL is empty, use URL from request
+    url = resp$url %||% req$url$url,
     status_code = resp$status_code,
-    request_headers = c('User-Agent' = req$options$useragent, req$headers),
+    request_headers = c("User-Agent" = req$options$useragent, req$headers),
     response_headers = {
       if (all(hz_namez(headers))) headers else last(headers)
     },
@@ -47,10 +52,10 @@ build_crul_response <- function(req, resp) {
 }
 
 #' Build a crul request
-#' @export
+#' @keywords internal
 #' @param x an unexecuted crul request object
 #' @return a crul request
-build_crul_request = function(x) {
+build_crul_request <- function(x) {
   headers <- x$headers %||% NULL
   auth <- check_user_pwd(x$options$userpwd) %||% NULL
   if (!is.null(auth)) {
@@ -72,7 +77,9 @@ build_crul_request = function(x) {
 
 #' @rdname Adapter
 #' @export
-CrulAdapter <- R6::R6Class("CrulAdapter", 
+#' @keywords internal
+CrulAdapter <- R6::R6Class(
+  "CrulAdapter",
   inherit = Adapter,
   public = list(
     #' @field client HTTP client package name
@@ -80,28 +87,26 @@ CrulAdapter <- R6::R6Class("CrulAdapter",
     #' @field name adapter name
     name = "CrulAdapter"
   ),
-  
   private = list(
     pluck_url = function(request) request$url$url,
     mock = function(on) crul::mock(on),
-    build_request   = build_crul_request,
-    build_response  = build_crul_response,
-
+    build_request = build_crul_request,
+    build_response = build_crul_response,
     fetch_request = function(request) {
       private$build_response(request, webmockr_crul_fetch(request))
     },
-
     request_handler = function(request) vcr::RequestHandlerCrul$new(request),
-
     update_vcr_disk_path = function(response) {
       write_disk_path <- vcr::vcr_configuration()$write_disk_path
-      
+
       # if crul_resp$content is character, it must be a file path (I THINK?)
       if (is.null(write_disk_path)) {
-        stop("if writing to disk, write_disk_path must be given; ",
-             "see ?vcr::vcr_configure")
+        abort(c(
+          "if writing to disk, write_disk_path must be given",
+          "see ?vcr::vcr_configure"
+        ))
       }
-      
+
       response$content <- file.path(
         write_disk_path,
         basename(response$content)
