@@ -1,9 +1,9 @@
 #' Build a httr response
 #' @export
+#' @keywords internal
 #' @param req a request
 #' @param resp a response
 #' @return a httr response
-
 build_httr_response <- function(req, resp) {
   try_url <- tryCatch(resp$url, error = function(e) e)
 
@@ -11,7 +11,8 @@ build_httr_response <- function(req, resp) {
     url = try_url %|s|% req$url,
     status_code = as.integer(resp$status_code),
     headers = {
-      if (grepl("^ftp://", resp$url %||% "")) { # in case uri_regex only
+      if (grepl("^ftp://", resp$url %||% "")) {
+        # in case uri_regex only
         list()
       } else {
         hds <- resp$headers
@@ -60,21 +61,21 @@ httr_cookies_df <- function() {
   df
 }
 
-# x = "https://foobar.com"
-# check_user_pwd(x)
 check_user_pwd <- function(x) {
-  if (is.null(x)) return(x)
+  if (is.null(x)) {
+    return(x)
+  }
   if (grepl("^https?://", x)) {
-    stop(sprintf("expecting string of pattern 'user:pwd', got '%s'", x))
+    abort(c("expecting string of pattern 'user:pwd'", sprintf("got '%s'", x)))
   }
   return(x)
 }
 
 #' Build a httr request
-#' @export
+#' @keywords internal
 #' @param x an unexecuted httr request object
 #' @return a httr request
-build_httr_request = function(x) {
+build_httr_request <- function(x) {
   headers <- as.list(x$headers) %||% NULL
   auth <- check_user_pwd(x$options$userpwd) %||% NULL
   if (!is.null(auth)) {
@@ -97,15 +98,15 @@ build_httr_request = function(x) {
 }
 
 #' Turn on `httr` mocking
-#' 
+#'
 #' Sets a callback that routes `httr` requests through `webmockr`
-#' 
+#'
 #' @export
 #' @param on (logical) set to `TRUE` to turn on, and `FALSE`
 #' to turn off. default: `TRUE`
 #' @return Silently returns `TRUE` when enabled and `FALSE` when disabled.
 httr_mock <- function(on = TRUE) {
-  check_for_pkg("httr")
+  check_installed("httr")
   webmockr_handle <- function(req) {
     webmockr::HttrAdapter$new()$handle_request(req)
   }
@@ -119,7 +120,9 @@ httr_mock <- function(on = TRUE) {
 
 #' @rdname Adapter
 #' @export
-HttrAdapter <- R6::R6Class("HttrAdapter",
+#' @keywords internal
+HttrAdapter <- R6::R6Class(
+  "HttrAdapter",
   inherit = Adapter,
   public = list(
     #' @field client HTTP client package name
@@ -127,17 +130,12 @@ HttrAdapter <- R6::R6Class("HttrAdapter",
     #' @field name adapter name
     name = "HttrAdapter"
   ),
-
   private = list(
     pluck_url = function(request) request$url,
-
     mock = function(on) httr_mock(on),
-
-    build_request   = build_httr_request,
-    build_response  = build_httr_response,
-
+    build_request = build_httr_request,
+    build_response = build_httr_response,
     request_handler = function(request) vcr::RequestHandlerHttr$new(request),
-
     fetch_request = function(request) {
       METHOD <- eval(parse(text = paste0("httr::", request$method)))
       METHOD(
@@ -147,7 +145,7 @@ HttrAdapter <- R6::R6Class("HttrAdapter",
         httr::add_headers(request$headers),
         if (!is.null(request$output$path)) {
           httr::write_disk(request$output$path, TRUE)
-        } 
+        }
       )
     }
   )
