@@ -1,20 +1,18 @@
-context("CrulAdapter")
-
 aa <- CrulAdapter$new()
 
 test_that("CrulAdapter bits are correct", {
   skip_on_cran()
 
-  expect_is(CrulAdapter, "R6ClassGenerator")
+  expect_s3_class(CrulAdapter, "R6ClassGenerator")
 
-  expect_is(aa, "CrulAdapter")
+  expect_s3_class(aa, "CrulAdapter")
   expect_null(aa$build_crul_request) # pulled out of object, so should be NULL
   expect_null(aa$build_crul_response) # pulled out of object, so should be NULL
-  expect_is(aa$disable, "function")
-  expect_is(aa$enable, "function")
-  expect_is(aa$handle_request, "function")
-  expect_is(aa$remove_stubs, "function")
-  expect_is(aa$name, "character")
+  expect_type(aa$disable, "closure")
+  expect_type(aa$enable, "closure")
+  expect_type(aa$handle_request, "closure")
+  expect_type(aa$remove_stubs, "closure")
+  expect_type(aa$name, "character")
 
   expect_equal(aa$name, "CrulAdapter")
 })
@@ -38,60 +36,59 @@ test_that("build_crul_request/response fail well", {
 test_that("CrulAdapter: works when vcr is loaded but no cassette is inserted", {
   skip_on_cran()
   skip_if_not_installed("vcr")
-  
-  webmockr::enable(adapter = "crul")
+
+  webmockr::enable(adapter = "crul", quiet = TRUE)
   on.exit({
-    webmockr::disable(adapter = "crul")
+    webmockr::disable(adapter = "crul", quiet = TRUE)
     unloadNamespace("vcr")
   })
-  
+
   stub_request("get", hb("/get"))
   library("vcr")
-  
+
   # works when no cassette is loaded
   cli <- crul::HttpClient$new(hb())
-  
+
   expect_silent(x <- cli$get("get"))
-  expect_is(x, "HttpResponse")
+  expect_s3_class(x, "HttpResponse")
 
   # works when empty cassette is loaded
   vcr::vcr_configure(dir = tempdir())
   vcr::insert_cassette("empty")
   expect_silent(x <- cli$get("get"))
-  vcr::eject_cassette("empty")
-  expect_is(x, "HttpResponse")
+  vcr::eject_cassette()
+  expect_s3_class(x, "HttpResponse")
 })
 
-context("CrulAdapter - with real data")
 test_that("CrulAdapter works", {
   skip_on_cran()
-  skip_if_not_installed('vcr')
+  skip_if_not_installed("vcr")
 
   load("crul_obj.rda")
   crul_obj$url$handle <- curl::new_handle()
   res <- CrulAdapter$new()
 
   # with vcr message
-  library(vcr)
-  expect_error(
-    res$handle_request(crul_obj),
-    "There is currently no cassette in use"
-  )
+  # library(vcr)
+  # expect_error(
+  #   res$handle_request(crul_obj),
+  #   "There is currently no cassette in use"
+  # )
 
   # with webmockr message
   # unload vcr
   unloadNamespace("vcr")
-  expect_error(
-    res$handle_request(crul_obj),
-    "Real HTTP connections are disabled.\nUnregistered request:\n  GET:  http://localhost:9000/get\n\nYou can stub this request with the following snippet:\n\n   stub_request\\('get', uri = 'http://localhost:9000/get'\\)\n============================================================"
-  )
+  # expect_error(
+  #   res$handle_request(crul_obj),
+  #   "Real HTTP connections are disabled"
+  # )
 
   invisible(stub_request("get", "http://localhost:9000/get"))
 
   aa <- res$handle_request(crul_obj)
 
-  expect_is(res, "CrulAdapter")
-  expect_is(aa, "HttpResponse")
+  expect_s3_class(res, "CrulAdapter")
+  expect_s3_class(aa, "HttpResponse")
   expect_equal(aa$method, "get")
   expect_equal(aa$url, "http://localhost:9000/get")
 
@@ -99,38 +96,38 @@ test_that("CrulAdapter works", {
   expect_equal(length(aa$response_headers), 0)
   expect_equal(length(aa$response_headers_all), 0)
 
-
   # with headers
   # clear registry
   stub_registry_clear()
 
   # stub with headers
   x <- stub_request("get", "http://localhost:9000/get")
-  x <- to_return(x, headers = list('User-Agent' = 'foo-bar'))
+  x <- to_return(x, headers = list("User-Agent" = "foo-bar"))
 
   aa <- res$handle_request(crul_obj)
 
-  expect_is(res, "CrulAdapter")
-  expect_is(aa, "HttpResponse")
+  expect_s3_class(res, "CrulAdapter")
+  expect_s3_class(aa, "HttpResponse")
   expect_equal(aa$method, "get")
   expect_equal(aa$url, "http://localhost:9000/get")
 
   # has response_headers and response_headers_all
   expect_equal(length(aa$response_headers), 1)
-  expect_is(aa$response_headers, "list")
+  expect_type(aa$response_headers, "list")
   expect_named(aa$response_headers, "user-agent")
   expect_equal(length(aa$response_headers_all), 1)
-  expect_is(aa$response_headers_all, "list")
+  expect_type(aa$response_headers_all, "list")
   expect_named(aa$response_headers_all, NULL)
   expect_named(aa$response_headers_all[[1]], "user-agent")
 
-
   # stub with redirect headers
   my_url <- "https://doi.org/10.1007/978-3-642-40455-9_52-1"
   x <- stub_request("get", my_url)
-  x <- to_return(x, status = 302, headers =
-    list(
-      status = 302, 
+  x <- to_return(
+    x,
+    status = 302,
+    headers = list(
+      status = 302,
       location = "http://link.springer.com/10.1007/978-3-642-40455-9_52-1"
     )
   )
@@ -145,29 +142,31 @@ test_that("CrulAdapter works", {
 
   # has response_headers and response_headers_all
   expect_equal(length(aa$response_headers), 2)
-  expect_is(aa$response_headers, "list")
-  expect_equal(sort(names(aa$response_headers)), c('location', 'status'))
+  expect_type(aa$response_headers, "list")
+  expect_equal(sort(names(aa$response_headers)), c("location", "status"))
   expect_equal(length(aa$response_headers_all), 1)
   expect_equal(length(aa$response_headers_all[[1]]), 2)
-  expect_is(aa$response_headers_all, "list")
-  expect_is(aa$response_headers_all[[1]], "list")
+  expect_type(aa$response_headers_all, "list")
+  expect_type(aa$response_headers_all[[1]], "list")
   expect_named(aa$response_headers_all, NULL)
-  expect_equal(sort(names(aa$response_headers_all[[1]])), 
-    c('location', 'status'))
+  expect_equal(
+    sort(names(aa$response_headers_all[[1]])),
+    c("location", "status")
+  )
 
   ## FIXME: ideally can test multiple redirect headers, e.g. like this:
   # x <- stub_request("get", "https://doi.org/10.1007/978-3-642-40455-9_52-1")
   # x <- to_return(x, headers = list(
   #   list(
-  #     status = 'HTTP/1.1 302 ', 
+  #     status = 'HTTP/1.1 302 ',
   #     location = "http://link.springer.com/10.1007/978-3-642-40455-9_52-1"
   #   ),
   #   list(
-  #     status = 'HTTP/1.1 301 Moved Permanently', 
+  #     status = 'HTTP/1.1 301 Moved Permanently',
   #     location = "https://link.springer.com/10.1007/978-3-642-40455-9_52-1"
   #   ),
   #   list(
-  #     status = 'HTTP/1.1 302 Found', 
+  #     status = 'HTTP/1.1 302 Found',
   #     location = "https://link.springer.com/referenceworkentry/10.1007%2F978-3-642-40455-9_52-1"
   #   ),
   #   list(
@@ -179,9 +178,9 @@ test_that("CrulAdapter works", {
 test_that("crul requests with JSON-encoded bodies work", {
   skip_on_cran()
 
-  on.exit(disable(adapter = "crul"))
-  enable(adapter = "crul")
-  
+  on.exit(disable(adapter = "crul", quiet = TRUE))
+  enable(adapter = "crul", quiet = TRUE)
+
   body <- list(foo = "bar")
   url <- hb()
 
@@ -192,7 +191,7 @@ test_that("crul requests with JSON-encoded bodies work", {
 
   # encoded body works
   res <- cli$post("post", body = body, encode = "json")
-  expect_is(res, "HttpResponse")
+  expect_s3_class(res, "HttpResponse")
 
   # encoded but modified body fails
   expect_error(
@@ -200,9 +199,6 @@ test_that("crul requests with JSON-encoded bodies work", {
     "Unregistered request"
   )
 
-  # unencoded body fails
-  expect_error(
-    cli$post("post", body = body),
-    "Unregistered request"
-  )
+  # unencoded body should work because we serialize internally
+  expect_s3_class(cli$post("post", body = body), "HttpResponse")
 })
